@@ -112,7 +112,7 @@ def _format(response):
         'card': {'id': response['customer_token']} if 'customer_token' in response else _format_card(response),
         'payment_day': date,
         'statement_descriptor': response['establishment_name'],
-        'payment_method_id': response['payment_method_id'],
+        'payment_method_id': str(response['payment_method_id']),
         'installments': response['installments'],
     }
     return result
@@ -157,7 +157,7 @@ class Payment(MuviBase):
             'site_id': site_id,
             'site_transaction_id': str(site_transaction_id),
             'token': payment_data['token'],
-            'payment_method_id': payment_data['payment_method_id'] if 'payment_method_id' in payment_data else 1,
+            'payment_method_id': int(payment_data['payment_method_id']) if 'payment_method_id' in payment_data else 1,
             'bin': payment_data['bin'],     # primeros 6 digitos de la tarjeta
             'currency': 'ARS',
             'payment_type': 'single',
